@@ -1,12 +1,13 @@
 from __future__ import annotations
 
 from enum import Enum, auto
-from typing import Optional
+from typing import List, Optional
 
 
 class ExecutionType(Enum):
-    BUY = auto()
+    EOD = auto()
     SELL = auto()
+    BUY = auto()
     WAIT = auto()
 
     @staticmethod
@@ -14,5 +15,9 @@ class ExecutionType(Enum):
         v: str = value.upper().replace(" ", "-").replace("-", "_")
         return ExecutionType[v]
 
+    @staticmethod
+    def by_priority() -> List[ExecutionType]:
+        return [ExecutionType.SELL, ExecutionType.EOD, ExecutionType.BUY]
+
     def value(self) -> str:
         return self.name.lower()
