@@ -27,36 +27,48 @@ class PercentageFocus(Focus):
     sell_at_end_of_day: bool
 
     def evaluate_buy(
-            self, symbol: str, news: List[News], current_price: float, candles: Dict[str, Candle], logger: Logger
+        self, symbol: str, news: List[News], current_price: float, candles: Dict[str, Candle], logger: Logger
     ) -> Tuple[bool, str]:
         open_price: float = candles[list(candles.keys())[-1]].open
         diff: float = (current_price - open_price) / open_price * 100
-        message: str = f"buy per: {open_price} versus {current_price} = {float_to_percentage_str(diff)}"
 
-        logger.debug(message)
+        if diff > self.percentage_up:
+            buy_message: str = (
+                f"Buy as {symbol} is up over threshold. {float_to_percentage_str(diff)} vs "
+                + f"{float_to_percentage_str(self.percentage_up)}. Current and Open prices: "
+                + f"({current_price} vs. {open_price})."
+            )
 
-        if (current_price - open_price) / open_price * 100 > self.percentage_up:
-            return True, message
+            return True, buy_message
 
-        return False, message
+        wait_message: str = (
+            f"Wait as {symbol} is not up over threshold {float_to_percentage_str(diff)} vs "
+            + f"{float_to_percentage_str(self.percentage_up)}. Current and Open prices: "
+            + f"({current_price} vs. {open_price})."
+        )
+        return False, wait_message
 
     def evaluate_sell(
-            self, lot: Lot, news: List[News], current_price: float, candles: Dict[str, Candle], logger: Logger
+        self, lot: Lot, news: List[News], current_price: float, candles: Dict[str, Candle], logger: Logger
     ) -> Tuple[bool, str]:
         threshold: float = (current_price - lot.purchase_price) / lot.purchase_price * 100
 
         if threshold > self.percentage_window.ceiling:
-            message: str = f"""{lot.symbol} with purchase price {current_price} is {threshold} over {lot.purchase_price}.
-                            Selling"""
-            logger.debug(message)
+            over_sell_message: str = (
+                f"{lot.symbol} with purchase price {current_price} is {threshold} over "
+                + f"{lot.purchase_price}. Selling"
+            )
+            logger.debug(over_sell_message)
 
-            return True, message
+            return True, over_sell_message
         elif threshold < self.percentage_window.floor:
-            message: str = f"""{lot.symbol} with purchase price {current_price} is {threshold} under {lot.purchase_price}.
-                            Selling"""
-            logger.debug(message)
+            under_sell_message: str = (
+                f"{lot.symbol} with purchase price {current_price} is {threshold} under "
+                + f"{lot.purchase_price}. Selling"
+            )
+            logger.debug(under_sell_message)
 
-            return True, message
+            return True, under_sell_message
 
         return False, f"Sell per: {lot.purchase_price} versus {current_price} = {float_to_percentage_str(threshold)}"
 
